.. _CMD:

*************************
CAMELS Multifield Dataset
*************************

The ``CMD`` folder contains the CAMELS Multifield Dataset, CMD, a collection of hundreds of thousands of 2D maps and 3D grids generated from the simulations of the CAMELS project.

We note that the data structure in CMD is different to the generic one described in :ref:`suite_folders`. We refer the user to the `CDM documentation <https://camels-multifield-dataset.readthedocs.io>`_ for details on the data structure and how to read and manipulate this data.

.. figure:: movie.gif
